# Changelog

Version 0.2:
  - Add Brython support for running locally in a browser and in the web interface
  - Corrections to output generation, mostly related to multistate data (note that
    it is not recommended to run on multistate data yet)

Version 0.1:
  - First public release
